# Dosuby

Dosuby is a tool developed in Python that aims to enumerate subdomains of a parent domain. It uses multiple techniques for enumeration, allowing for a comprehensive subdomain scan. Additionally, Dosuby has the option to scan the enumerated domains.
   ```

## Usage

```
pip install dosuby
```

```
dosuby
```
The above command will start the tool

![dosuby Image](imgs/dosuby.png)

Default enumeration

![dosuby_gif_1 Gif](imgs/dosuby_gif.gif)

Enumeration with scan

![dosuby_gif_2 Gif](imgs/dosuby_gif_2.gif)

## Contributing

Contributions are welcome! If you find a bug or would like to suggest a new feature, please open an issue or submit a pull request.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.
